#
# spec file for package sigil
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sigil
Version:        0.9.10
Release:        2.2
Summary:        WYSIWYG Ebook Editor
License:        GPL-3.0-only
Group:          Productivity/Other
Url:            http://sigil-ebook.com/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        https://github.com/Sigil-Ebook/Sigil/archive/%{version}.tar.gz
Source1:        https://github.com/Sigil-Ebook/Sigil/raw/master/docs/Sigil_User_Guide.epub
Source2:        %{name}.desktop
# PATCH-FIX-OPENSUSE Disabled __DATE__ and __TIME__ which is replaced later in pre section
Patch0:         %{name}-gt-0.9.0-Dialogs-About.cpp.patch
BuildRequires:  boost-devel
BuildRequires:  cmake >= 3.0
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hunspell-devel
BuildRequires:  libqt5-qtbase-devel >= 5.4.2
BuildRequires:  libqt5-qtlocation-devel >= 5.4.2
BuildRequires:  libstdc++-devel
BuildRequires:  libxerces-c-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  make
BuildRequires:  pcre-devel
BuildRequires:  python3-devel >= 3.4
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebChannel)
BuildRequires:  pkgconfig(Qt5WebKit)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5XmlPatterns)
# not need for build, only check for exists
BuildRequires:  python3-html5lib
BuildRequires:  python3-lxml
BuildRequires:  python3-six
BuildRequires:  python3-tk
#BuildRequires:  python3-regex
BuildRequires:  python3-Pillow
BuildRequires:  python3-cssselect
BuildRequires:  python3-cssutils
#BuildRequires:  python3-chardet
Requires:       python3-html5lib
Requires:       python3-lxml
Requires:       python3-six
Requires:       python3-tk
#Requires:       python3-regex
Requires:       python3-Pillow
Requires:       python3-cssselect
Requires:       python3-cssutils
#Requires:       python3-chardet

%description
Sigil is an editor for the EPUB format. It is designed for WYSIWYG
editing of EPUB files and for converting other formats to EPUB. It
also provides support for direct XHTML, CSS and XPGT editing. You can
use it to add any of the metadata entries supported by the EPUB
specification and create a hierarchical Table of Contents.

%prep
%setup -q -n Sigil-%{version}
%patch0 -p 1
cp -v %{S:1} .
cp -v %{S:2} .
# rpmlint

#FIXME MANUAL UPDATE OF DATE REQUIRED HERE!!!!
# Fix "Your file uses  __DATE and __TIME__ this causes the package to rebuild 
# when not needed warning"
# http://sourceforge.net/tracker/?func=detail&atid=102439&aid=3314371&group_id=2439
#
# We use the ChangeLog date
_date=$(date -u -r ChangeLog.txt -I)
_time=$(date -u -r ChangeLog.txt +%%T)
# Change it:
find . -type f -name About.cpp -exec sed -i "s/@DATE@/$_date/;s/@TIME@/$_time/g" {} +

sed -i 's/\r//' ChangeLog.txt README.md COPYING.txt
dos2unix src/Resource_Files/python3lib/meta*.py
dos2unix src/Resource_Files/python3lib/opf_*.py
find . -type f -exec sed -i -e 's|#!\/usr\/bin\/env python|#!\/usr\/bin\/python3|g' {} +

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"

cmake -G "Unix Makefiles" \
   -DCMAKE_INSTALL_PREFIX=%_prefix \
   -DCMAKE_BUILD_TYPE=Release .

make %{?_smp_mflags}

%install
%make_install

# create a .desktop file:
mkdir -p %{buildroot}%{_datadir}/applications

# install icons for the .desktop file
install -m644 -D src/Resource_Files/icon/app_icon_16.png %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/sigil.png
install -m644 -D src/Resource_Files/icon/app_icon_32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/sigil.png
install -m644 -D src/Resource_Files/icon/app_icon_48.png %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/sigil.png
install -m644 -D src/Resource_Files/icon/app_icon_128.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/sigil.png
install -m644 -D src/Resource_Files/icon/app_icon_256.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/sigil.png
install -m644 %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

%suse_update_desktop_file %name
%fdupes -s %buildroot

%files
%defattr(-,root,root)
%doc ChangeLog.txt README.md COPYING.txt Sigil_User_Guide.epub
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor/
%dir %{_datadir}/icons/hicolor/16x16
%dir %{_datadir}/icons/hicolor/16x16/apps
%dir %{_datadir}/icons/hicolor/32x32
%dir %{_datadir}/icons/hicolor/32x32/apps
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/apps
%dir %{_datadir}/icons/hicolor/128x128
%dir %{_datadir}/icons/hicolor/128x128/apps
%dir %{_datadir}/icons/hicolor/256x256
%dir %{_datadir}/icons/hicolor/256x256/apps
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/pixmaps/*.png
%dir %{_datadir}/%name
%dir %{_datadir}/%name/translations
%{_datadir}/%{name}/translations/*
%dir %{_datadir}/%name/*dictionaries
%{_datadir}/%{name}/*dictionaries/*
%{_datadir}/%{name}/examples
%{_datadir}/%{name}/python3lib
%dir %{_datadir}/%{name}/polyfills
%{_datadir}/%{name}/polyfills/MathJax.js
%{_datadir}/%{name}/plugin_launchers
%dir /usr/lib/%name
/usr/lib/%{name}/*

%changelog
* Fri Sep 21 2018 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop build date from build output (boo#1047218)
- Fix %% escaping where %%H:%%M:%%S turned into 17:53:56OURCE
* Thu Aug 16 2018 jengelh@inai.de
- Replace old %%__ macros and $RPM_* shell vars.
- Use more "xargs -exec +".
* Wed Aug 15 2018 ecsos@opensuse.org
- update to 0.9.10
  * Bug Fixes
  - Fix signal handling to prevent double launch of plugins
    immediately after plugin installed
  - Fixed incorrect named entity tooltips for many of the
    Insert-> Special Characters
  - Fixed lack of recognition of woff2 fonts inside Sigil and for
    plugins
  - Fix segfault when .xml is first file in BookBrowser and add
    new html or split at cursor is invoked
  - Fix bug that allowed multiple audio/video tabs of the same
    resource to be opened
  - Fix plugin related bug when adding/removing last xhtml file
  - Fix Text Direction setting inside body to use structural dir
    attribute under epub3
  - Fix duplicate group-position property in epub3 MetaData
    Editor
  - Use absolute path references when first opening Sigil with
    an ebook so that Open Recent works better
  - Fix "issue" in handling self-closing script tags in head
    (similar issue that we had with self-closing title tags)
  - Fix issue converting Qt Strings to their Python equivalent
    when outside the BMP
  - Fix issue with trying to add existing html files when names
    clash due to case insensitive file systems
  - Fix crash bug after styling text in BookView and immediately
    going to CodeView without moving cursor
  - Fix crash bugs after deleting resources contained in a Report
    in the BookBrowser
  - Fix bug that destroys nav if left in unparseable state by
    user even temporarily
  - Fix bug that moved cursor to beginning of tag block when save
    is done in CodeView
  * New Features
  - allow plugins to supply their own icon (plugin.png 48x48) for
    use on the Quick Launch Toolbar icons
  - extend plugin interface to include the status of the epub
    inside Sigil (modified or saved)
  - extend plugin interface to include the path to the saved epub
    file or the null string if never saved
  - extend Insert->Special Characters to include both a Greek
    letter panel and a mathematical symbol panel
  - add support for calibre:series and calibre:series_index to
    Metadata Editor for epub2
  - add support for calibre:title_sort to Metadata Editor for
    epub2
  - add support for clicking internal links in Preview to load
    the proper destination tab
  - add support for loading Qt's base translation files if
    present. Allows buttons on native qt dialogs to
  - be translated (Windows users may need to manually copy newer
    qtbase_xx.qm files to Sigil's translation
  - directory if they didn't exist in Qt5.6.2)
  - allow user to add custom css rules to Preview/Book View by
    creating a file called "custom_preview_style.css"
  - in the Sigil preferences folder (not responsible for custom
    css and ebook css fighting with each other)
- Drop sigil-fix_deprecated_macro.patch because now in upstream.
* Mon Jun 11 2018 ecsos@opensuse.org
- insert sigil-fix_deprecated_macro.patch to fix build error
* Sun Jan  7 2018 ecsos@opensuse.org
- update to 0.9.9
  * Bug Fixes
  - Add python_3.5_fixes3.patch to Python build and update build
    docs on OSX to fix missing symbols
  - Fix crash caused by Preview holding pointer to user removed
    resource when front tab is non-html resource
  - Fix crash in FlowTab destructor due to re-entering flowtab
    during Syntax Highlighting and signals
  - Fix issue with file icons disappearing when reordering in
    Book Browser (commit ecb56b1f)
  - Fix missing epub3 Manifest cover-image property
    setting/unsetting with BookBrowser
  - Fix issue where cancelling the SaveAs dialog disconnected
    an existing epub from its saved path
  - Fix assertion error in sigil-gumbo when handling extraneous
    script end tags
  - Apply multiple fixes for gumbo from upstream
  - Fix segfault in Split at Cursor when not an html file
  - Make sure Add Cover tool properly handles existing manifest
    cover properties in EPUB3s
  - Correct error dialog to say “Sigil may need to close.”
  - Prevent Images and Misc items from being dragged to the Text
    folder in Book Browser (commit 30bb96d)
  - Fix Linux bug that prevents rich text from other programs
    being pasted into Book View (issue #320)
  - Fix bug where index entries inside em and dfn tags were
    ignored during index generation
  - Fix bug on Windows in spell checking when smart right single
    quotes are used for apostrophes
  - Fix bug in simple well-formed check to handle generic xml
    processing instructions
  - Fix bug in epub3 MetaEditor with title-type
    and collection-type properties
  - Fix plugin code to prevent book href vs manifest id clashes
  - Fix bug in Plugin Runner to allow it to delete non-manifested
    files properly
  - Fix bug in SourceUpdates to handle properly handle
    css properties with multiple urls
  - Fix bugs in well-formed check to better handle missing
    doctypes
  * New Features
  - Add SIGIL_DISABLE_CURSOR_BLINK environment variable
    to disable text cursor to aid Accessibility on OSX
  - Better use semantic information (guide types and Landmarks)
    to allow the user finer control of index generation
  - Attempt to improve Metadata Editor placeholder text to help
    beginners
  - Preview Window Title bar will now show height and width
    of the Preview Window
  - Allow users to limit/disable clipboard history saving via
    General Preferences
  - Convert br tags in header text to linebreaks for toc/ncx/nav
    generation routines
  - Support spell checking of words with numbers controlled by
    Preference settings
  - Add two additional Quick Lauch Icons for Plugins
- Drop Patch sigil-version.patch,
  because right version is now in upstream
* Sat Apr  1 2017 ecsos@opensuse.org
- update to 0.9.8
  * Bug Fixes
  - Make sure when new empty epub3's are created that the toc
    does not use a doctype (Issue #250)
  - Make GetUniqueFilenameVersion work even on Case-Insensitive
    filesystems (Issue #247)
  - Properly urlencode/decode all hrefs in plugin's ResultXML in
    launcher/PluginRunner to prevent parse errors
  - Enable Basic Cut Copy Paste Icons/Actions in OPF, NCX, XML,
    SVG, and other Misc Text Tabs
  - Add proper detection for minimum service pack requirements in
    Windows installer
  - Include workaround for bug in KDE Qt5 plugin on Linux that
    keep plugins from launching from menu
  - Prevent splitting Section0001.xhtml (Split at Cursor)
    needlessly rewrite the file's manifest id with a uuid
  - Fix issue where merging files when non-xhtml tabs were open
    was causing Python errors or crashes
  - Fix segfault in Image Reports when deleting unused image
    files
  - Fix bug in prettyprint_xhtml in sigil_bs4 (put back
    inadvertently dropped is_void_tag routine)
  - Fix gumbo serialize to better handle injected newlines
  - Harden bundled Python isolation on Windows and add subset of
    PyQt5 to bundled modules
  - Harden plugin interface code to properly unquote/quote hrefs
  - Stop Sigil from nagging about unsupported mimetypes when
    epubs with Adobe xpgt page-templates are opened
  - Fix Book Browser highlighting issue when editable XML files
    from the "Misc" folder are opened
  - Pull upstream bug fixes from google's gumbo parser for Sigil
  - Force formatting buttons in BookView to generate
    inline-styled spans instead of "strike", "b", etc
  - Fix bug from deprecated use of jquery $.browser.msie
    introduced when jQuery was updated
  - Fix temp folder specification on Windows systems that delete
    the system temp folder for every login (Issue #285)
  - Fix typos in metadata descriptions to allow better
    translations
  * New Features
  - New preference setting (Appearance section) which allows user
    to adjust the size of the main menu icons
  - Add manifest properties to Book Browser tooltips and to All
    Files Reports Widget for epub3
  - Make Sigil's UI and spellchecker language settings available
    to plugins
  - Add support for PyQt5 for plugin gui widgets
  - Internal builds now use Qt 5.6.2 with Webkit added back
  - Windows structural changes to eliminate file duplication and
    to accommodate PyQt5 requirements
  - Update all build it yourself from source documentation for
    new requirements
- Add Patch sigil-version.patch to set right version
* Wed Feb  8 2017 jengelh@inai.de
- Trim redundant mentions from description
- Use %%_smp_mflags for parallel build
* Tue Nov 29 2016 ecsos@opensuse.org
- update to 0.9.7
  * Bug Fixes
  - Allow tags in the svg and mathml namespace to automtically
    self-close if empty to help work around a bug in Kindlegen
    that will not seem to accept a closing svg image tag even
    though image is non-void
  - Prevent TextTab from constantly recentering page when focus
    is lost
  - Fix bugs in plugin basename_to_id when used with xpgt files
    or any unrecognized extensions
  - Fix typos in pls mimetype in plugins
  - Fix code synchronization issues among 3 places where file
    extensions are mapped to mimetypes
  - Fix plugin readotherfile interface to rebuild the opf on the
    fly only if it has been modified
  - Fix plugin validation issues with integer vs string
    representations of line number and character offsets
  - Fix duplicate filename in multiple directories bug when
    updating CSS urls
  - Fix bug in page-map.xml mimetype when “Add Existing …” is
    used
  - Fix undefined behaviour shifting signed negative values in
    3rdparty libs and fix many warnings
  - Fix text vs binary file type recognition in the plugin
    interface (CSS and js files are text not binary)
  - Fix too small toolbar icons on high dpi displays
  - Fix bug that caused text highlighting to get lost on some
    systems when doing a CSS Find & Replace.
  - Fix bug in plugin interface basename_to_id to recognize .htm
    extensions
  - Fix bug in epub3 semantic popups to always refect the local
    name of epub:type setting
  - Fix bug where creation on an HTML TOC could overwrite an
    existing Nav under epub3
  - Fix manifest id not starting with alpha character bug
  * New Features
  - Extend validation plugin interface with add_extended_result()
    method to allow better cursor positioning
  - Extend TextTab and Tabs derived by it to position cursor based
    on offset
  - Allow editing of page-map.xml files, xpgt files and other
    misc xml based files inside Sigil
  - Update Windows builds use Python 3.5.2, VS2015
  - Update Mac OS X builds and build instructions to use
    Python-3.5.2
  - Remove support for python2.7 only plugins and simply Manage
    Plugins settings
  - Update to Qt 5.6.1-1 with QtWebKit added back for release
    builds for Windows (VS2015) and Mac OSX
  - Update Mac OS X and Linux build instruction documentation for
    recent changes
  - Allow Linux Dictionaries to look up default paths for
    dictionaries passed in by build cmake settings
  - Make the columns in the Manage Plugins table be sortable by
    the user
  - Better detect undefined and non-existing url fragments to
    prevent issues when splitting or merging files
  - Make tooltips for Run Plugin Icons show the name of the
    selected plugin on hover
  - Upgrade from jquery 1.6.2 to version 2.2.4
  - Upgrade from jquery.scrollTo 1.4.2 to version 2.1.2
  - Upgrade to double sized 48×48 pixel icons for High DPI
    displays, Special Thanks to PatNY for creating our icons
* Fri Jul  1 2016 ecsos@opensuse.org
- update to 0.9.6
  * Bug Fixes
  - Make StdWarningDialog resizeable when “Show Details” is used
  - Fix CleanSource svg prefix removal bug that sometimes broke
    valid svg code
  - Remove svg image and html5 menuitem from the list of void
    elements in the Sigil and plugin code
  - Properly xml escape “&” in metadata attribute values
  - Properly perform source updates on epub on load even when
    they do not follow recommended spec
  - Make handling of comments in both xhtml and xml more robust
  - Properly url escape css file names to handle css files with
    spaces in them
  - Try to make direct editing of content.opf more safe by
    auto-fixing errors when possible
  - Properly handle WellFormed checks for pure XML in
    XMLResource.cpp by using embedded python3 lxml
  - Make opf_newparser.py and xmlprocessor.py more robust to
    broken user input in content.opf
  - Make ProcessXML (repairXML in xmlprocessor.py) – leave
    untouched anything well-formed
  - Fix thinko in plugin bookcontainer.py and outputcontainer.py
    contributed by wrCisco
  - Fix for improper encoding in plugins on Mac OS X due to
    missing inherited plugin environment
  - Fix for typos in epub xmlns when splitting epub3 ebooks in
    BookView
  - Update testplugin_v012.zip to testplugin_v013.zip to handle
    sgc-nav.css new feature
  - Fix bugs in DeleteUnusedStyles when selector exists more than
    once in the same stylesheet
  - Fix bugs in DeleteUnusedStyles when group selectors span more
    than one line
  - Fix bugs in Reports: CSS Styles missing cases when selector
    exists more than once
  - Fix bug in Reports: All Files to use Landmark Semantics under
    epub3 not guide semantics
  - Fix bug, slow in loading ini when too large clipboard
    history, user can now delete them via dialog
  - Stop cosmetic double-spaces being introduced into OPF
    manifest, spine and guide entries
  - Prevent bug when user selects too much in BookView and then
    tries to change case
  - Fix bug in Delete Unused Media when css urls do not use
    quotes
  - vTry to set all ways of updating the ncx to use 2 character
    indentation of head element
  - Fix Building Relocatable Python on Mac build instructions
    to remove BeautifulSoup4 requirement
  - Fix for generating empty guide for epub3 when in plugins
  * New Features
  - created sgc-nav.css stylesheet for nav and allow templates in
    Prefs Dir for user to control it
  - Added General Setting to allow user to set own temporary
    directory location
  - Added Qt Stylesheet support – Recognize and load
    “qt_styles.qss” file if stored in Sigil Preferences folder
  - Extended the plugin interface to add support for epub3
    bindings elements
  - Add option + forward delete shortcut to active Metadata
    Editor remove
* Fri Apr 15 2016 ecsos@opensuse.org
- update to 0.9.5
  * Bug Fixes
  - Fix regression when ImportHTML in gathering HTML based
    DC. metadata
  - Fix regression - remove incorrect use of opf:scheme from
    dc:creator and dc:contributor under epub2
  - Fix regression - the guide reference tag is always a void tag
  - Fix issues with hunspell spell checking under Windows when
    non-ascii paths to dictionaries
  - Fix issues with overridding the prefs directory on Windows
    with non-ascii paths
  - Fix broken manual "Check" button on W3C stylesheet
    validation's generated html form.
  - Fix media-type recognition for .m4a and .m4v file extenstions
    in main Sigil and plugin code
  - Treat ruby and rt as inline tags when pretty-printing in
    Sigils and for plugins
  * New Feature
  - Allow user to choose what level of CSS gets used in the
    "Validate Stylesheets
    With W3C" tool via user preference (General).
* Tue Mar 15 2016 ecsos@opensuse.org
- update to 0.9.4
  * Bug Fixes
  - Prevent the use of zero length key fields when obfuscating
    fonts
  - IDPF font obfuscation key accepts all input except as
    specified
  - Fix typo in main.ui accelerator assignment
  - Update Transifex project URL
  - Prevent NCX Weirdness with ampersand added when editing NCX
    in codeview and TOC widget showing
  - Fix lost namespace attributes on metadata tag
  - Allow auto conversion from package version 1.0 to 2.0
  - Remove unused parameter from gumbo create_text_node
  - Fix bug that hits package version when no xml declaration
    on opf on import
  - Add id to Heading structure to greatly speed up NCX/TOC
    creation even more
  - Only the true nav should ever have the nav manifest property
    set
  - Prevent nav property from being overwritten when updating
    manifest properties
  - Prevent segfault if user add semantics but never chooses one
  - Prevent Add Cover from returning the wrong doctype for epub3
  - Make sure cover-image and svg (if needed) are added as epub3
    manifest properties when adding a cover
  - Make sure all referenced resources are found for Delete
    Unused Media
  - Remap non-standard epub namespace prefixes in the opf to
    those now reserved for epub3
  - Make loading epubs with broken opf files more robust
  * New Features
  - Extract all MarcRelators related code into its own class so
    it can be shared
  - Added some missing MARC relators
  - Removed obsolete MARC relators (ctb replaced clb, and sng
    replaces voc)
  - Completely redesign MetaEditor gui to work with both epub2
    and epub3 metadata
  - Add default metadata language and title for the user
  - Make the Nav a required part of an epub3 - create an empty
    one if need be
  - Create NavProcessor to use gumbo to update the nav.xhtml
  - Add support for Adding/Removing Nav Landmarks
  - Better identify the true nav when loading epub3s
  - Add ability to generate Nav TOC from Book Headings to
    CreateTOC tool
  - Check for valid nav otherwise create a new default one
    ready for updates
  - Do not allow split markers to be added to nav.xhtml
  - Do not allow nav to get merged
  - Do not allow the nav to be deleted
  - Do not allow plugins to delete the nav under epub3
  - Completely Revamp BookBrowser interface to support both Guide
    and Landmark Semantics
  - Create Semantics Dialog to better handle epub2 and epub3
    semantics
  - Create Separate Guide/Landmarks classes for epub2 and
    epub3 respectively
  - Rename DescriptiveMetaInfo structure to just
    DescriptiveInfo to work with guide/landmarks elements
  - Add a mapping from Landmark to Guide and Back
  - Remove old GuideSemantics code
  - Make sure Landmarks semantics show up in BookBrowser
    tooltips
  - Update epub3 semantic vocab in Landmarks
  - Completely Revamp how the dockable TableOfContents gui widget
    is built and updated
  - Remove strong coupling between TableOfContents widget
    and NCX
  - Allow dockable Table Of Contents to refresh from Nav
    under epub3
  - Large update for translations needed
  - Many new strings supporting the MetaEditor GUI and Add
    Semantics GUI were added
- update to 0.9.3
  * Bug Fixes
  - Add a python based updatechecker for Sigil updates to prevent
    Windows OpenSSL build issues
  - Stop 'Generate TOC' from introducing unnecessary spaces in
    front of class attibute values
  - Use localeAwareCompare to attempt to add Index Entries to
    build them sorted
  - Fix segfault caused by use of possibly stale htmlresource
    pointer in FlowTab destructor
  - Workaround Qt bug that causes slow selection/highlighting of
    xhtml on Linux
  - Fix multiple typos in sigil_gumbo_bs4_adapter code
  * New Features
  - Add an autostart/autoclose capability for plugin developers
  - Add 3 User-assignable ToolBar Buttons for up to 3 plugins -
    users can an assign key accelerators to them
  - Add General Settings Preference for setting default
    (epub 2 or 3) for new documents
  - Merge CleanSource Preference Settings into General Settings
    Preferences
  - Add Setting to control Epub access non-multimedia remote
    resources
  - Completely reworked Sigil internals to support epub version
    (2 or 3) specific functionality
  - ImportHTML, ImportEPUB, Splitting and Merging, Index
    Generation, Mending, are all now epub version aware
  - AddModificationDate upon save is now epub2 and epub3 aware
  - Add "Epub3 Tools" to the Tools menu
  - Add three new epub3 tools: "Update Manifest Properties",
    "Generate Nav From NCX" and
    "Generate NCX From Nav" to "Epub3 Tools" menu
  - Add local-storage support to PV/BV for epub3's that use
    javascripts
  - Added support to recognize and update upon load SMIL files
    and Adobe page-map.xml files
  - Make quoteurl url scheme-aware in both python and for Qt,
    since epub3 allows external resources
  - Extend url address recognition to include track, video, and
    object elements attributes
  - Recognize and store .vtt and .ttml files for video subtitles
    and captioning
  - Prevent attempts from using Metadata Editor gui from hurting
    epub3 until support is added later
  - Many epub3 related bug fixes and changes to make sure all new
    epub3 href/links are properly updated
  - Reworked the plugin_launcher epub3 interface code to allow
    fallback and media-overlay attributes
  - Added support for MathML in Preview via Mathjax.js-single
    polyfill
  - Added the MathML list of void tags to GumboInterface for
    proper serialization
  - Add technique to call long EmbeddedPython calls by using
    QtConcurrent::run
* Sat Dec 19 2015 ecsos@opensuse.org
- update to 0.9.2
  - Update BuildingOnLinux docs
  - Update Building on Mac OS X docs
  - Fix example clips/searches loading on Linux
  - Simplify UseBundledInterpreter Logic
  - Preliminary Linux binary installer support added
  - Include Pull Request 161 by pinotree "Switch TempFolder to
    QTemporaryDir" to improve safety
  - Fix bug when adding existing html links to stylesheets not
    being updated
  - Fix bug in Well-Formed error messages due to bug inside
    gumbo's error.c
  - Add xmlns="http://www.w3.org/1999/xhtml" attribute to html tag
    if missing
  - Reduce fear of Cleaning ToValidXHTML by using serialize not
    prettyprint
  - Add ability to change Sigil's user preferences directory by
    specifying a new path via the SIGIL_PREFS_DIR environment
    variable (path must be user-writable).
  - Fix lost DOCTYPE info when splitting or merging
  - Completely rework pretty printing via gumbo to be much more
    robust
  - Make identification and storage of page-map.xml more robust
  - Completely revamp Cleaning to use "Mend Code" and remove
    PrettyPrintGumbo as on option
  - Rename PrettyPrintGumbo to "Mend and Prettify" and move to
    CodeView Right-click menu
  - Restore Sigil's update checker that's been broken for a while
  - Update sigil_bs4 prettyprint_xhtml and serialize_xhtml routines
    to use logic of code in GumboInterface
  - Update sigil_bs4 to use numeric entities when faced with nbsp
    so they do not get lost later in Sigil
  - Rename "Sanity Check" to "Well-Formed Check EPUB" and remove
    check icon people confused with FlightCrew
  - Fix out of date error message referencing Tidy
  - Coerce missing or bad doctypes to meet either epub2 or epub3
    standard
  - Inject empty title tag if missing from head
  - Html escape Index entry text used to create index.html
* Mon Nov 30 2015 ecsos@opensuse.org
- update to 0.9.1
  - Fix bug when template sgc_toc.css could be changed to blank on
    save, since no InitialLoad() was done
  - Change order of TextResource m_IsLoaded and m_CacheInUse flags
    to minimize potentail race exposure.
  - Fix PluginRunner bug that introduced errors into xhtml files
    when both the content.opf and xhtml were modified
  - Auto XML Decode and Escape Metadata entries created in the
    Metadata GUI
  - Alter pluginhunspell.py so a missing libhunspell doesn't stop
    ALL plugins from working
  - default to using clean by gumbo vs prettyprint gumbo in new
    installs
  - fix prettyprint bug with trailing whitespace improperly
    inserted after inline tags inside div tags
  - fix for bundled interpreter packages PIL and cssutils on
    Mac OS X that were missing
  - Fix for crash when using Find in BV on pages with no text, only
    images (issue #156)
  - Added testplugin_v010.zip to docs to allow Linux packagers to
    test their plugin implementation
  - Fix for prettyprint bug with tables (issue # 158)
  - Fix for serialize in gumbo to limit injected returns
  - Update to Sigil_Plugin_Framework_rev6.epub
  - Make build order of sigilgumbo deterministic in order to help
    Linux packagers
  - Make plugin launcher success and error messages robust to
    non-utf-8 strings
  - Fix for crash bug when comments exist inside manifest of opf
  - Fix for Sigil's gumbo - only inject end tags when current token
    does NOT need to be reprocessed
* Sun Nov 29 2015 ecsos@opensuse.org
- update to 0.9.0
  - Add "Use Bundled Python" option to bring sanity and choice to
    Python3 Interpreter selection
  - Merge EmbeddedPython code across platforms and fix python flags
    for all platforms
  - Properly build translation base.ts to prevent blank message
    fields being generated by tr()
  - Allow PrettyPrint_Gumbo to condense whitespace where allowed
  - In PluginRunner auto-repair modified xml (opf, ncx), do not
    check xml with xhtml wellformed check
  - Fix bug in plugin epub3 interface, conversion of properties
    with null strings to None
  - Restore ability to override hunspell dictionary locations on
    Linux with SIGIL_DICTIONARIES env var
  - Restore ability to build Sigil against system hunspell
    libraries on Linux
  - Adjust pluginhunspell.py to try to find system hunspell if
    bundled hunspell is not built/installed
  - Fix hang/slowness in TOC creation when huge number of headings
    all exist in the same file
  - Performance speedups for NCX writing to help with slow ToC
    Creation
  - bug fix for better detecting comments in sanitycheck.py
  - bug fix for Adding Blank xhtml files to an epub3
  - bug fix for Issue 140 - TOC gets cut-off under some platforms
    (lxml needs utf-8 not unicode)
  - add cmake option INSTALL_BUNDLED_DICTS to enable/disable
    installation of bundled hunspell dictionaries
  - allow SIGIL_DICTIONARIES env var to specify multiple paths
    (colon delimited)
  - Fix bug in sanitycheck.py error message creation
  - Identify woff files as fonts when importing epubs
  - Fixes for nbsp being "lost" when linking in stylesheets and
    when splitting and merging chapters
  - Fix for lost whitespace inside text holding tags when pretty
    printing
  - Workaround for broken QShortCut in Qt 5.4.X see Issue 149
  - cleanup up some compiler warnigns
- changes from pre-release 0.8.901
  - Fixes
  - fix for hang when trying to add a cover
  - multiple fixes for segfaults in the TOC creation code
  - fixes for blank TOC headings caused by tags nested inside of
    h1-h6 tags
  - workaround for an instability caused by a compiler bug in
    Visual Studio 2013 on Windows
  - fixes for multiple xml header declarations appearing when
    using sigil_bs4 prettyprint_xhtml() or serialzie_xhtml()
  - build fixes to include MSVCR100.DLL for Windows machines that
    are too new to have it
  - fix pretty printing using gumbo to support some mbp: tags
  - fixes to deal with self-closing iframe tags which made gumbo
    stumble
  - fixes to more robustly convert from QByteArray types to their
    char * pointers
  - fixes and improvements to the Building on Linux instructions
  - protect gumbo parsing with a mutex to prevent unknown issues
    with potential for non-reentrant code in that library
  - workaround Qt QHash operator()= bugs that caused static QHash
    objects to freed multiple times
  - fix for internal opf processing encoding detection being
    confused by xml header declarations potentially resulting in
    missing spine and manifest items.
  - Features
  - new launcher/wrapper code interface to support plugins that
    operate on epub3 ebooks
  - added cssutils, cssselect, and chardet to the site-packages
    of the embedded Python 3.4 interpreter
  - validation plugins that report no errors will now have
    "No problems found" appear in the Sigil Validation window.
  - validation plugins will auto accept/close the plugin runner
    window no matter the results
  - Windows installer now detects whether MS redistributable
    runtimes are already installed
- changes from pre-release 0.8.900
  - Kill tidy and replace it with a combination of a specially
    modified Gumbo parser that supports html5
  - Kill Xerces and XercesExtras.
  - Kill Boost, replace with C++ 11
  - Kill unused bundles.
  - Replace all "undefined - behaviour" use of "Null" References
    with proper pointers across entire codebase to allow it to
    work with the latest clang compilers
  - Completely revamp the build process to embed the Python 3.4
    Interpreter inside of Sigil and integrate it in, including as
    site-packages: [lxml, bs4, PIL, regex, six, html5lib].
    This will allow plugins that use the internal Python 3.X
    engine access to all of these specialized packaes by default
    with no additional action needed by end users of their plugin.
  - Create our own version of BeautifulSoup4-4.4.0 called
    sigil_bs4 that fixes lxml namespace bugs, fixes
    serialization/prettyprinting of inline xhtml tags, and
    modifies the bs4 codebase so that a single sourcecode works
    equally well on both Python 2.7 and Python 3.X
  - Replace internal opf and ncx xml processing and cleaning with
    a combination of embedded Python 3.4, sigil_bs4 / lxml
  - Build hunspell as a shared library and then add a ctypes
    interface to allow plugins to spellcheck
  - Build our modified gumbo html5 parser as a shared library and
    provide a bs4 ctypes interface to it for easy xhtml
    processing in plugins that use Python 2.7 and Python 3.X
  - Allow plugins to auto-fix "text/html" media-types to
    "application/xhtml+xml"
  - Redesign the ebook source updates upon load process to use
    our modified gumbo-parser
  - Begin the transition to allow for both epub2 and epub3
    editing (Note: epub3 editing is still incomplete)
  - Convert Flightcrew to become a Sigil plugin and replace it
    with a simple and fast internal sanity checker.
  - Update Hunspell dictionaries to be actual dictioanries and
    not word lists for en_US and en_GB
  - Updated other dictionaries to their most current version to
    match what is used in LibreOffice 5
  - Fix issue #54 modified date using local numerials when it
    should be using Arabic numerals per the spec.
  - Set the book to modified when font's are obfuscated.
  - Change FORCE_BUNDLED_COPIES build flag to USE_SYSTEM_LIBS.
    This flips the meaning of the flag. Now USE_SYSTEM_LIBS will
    enable using system libraries. Also, SYSTEM_LIBS_REQUIRED was
    added which will fail the cmake configure if any system
    libraries are not found instead of falling back to the
    bundled copy. Finally, this makes the build more consistent
    for Windows and OS X users.
* Wed Jun 17 2015 ecsos@opensuse.org
- update to 0.8.7
  - This is a very small maintenance release.
    It mainly updates links for the change in code location.
* Sat Apr 18 2015 ecsos@opensuse.org
- update to 0.8.6
  - Fix for crash during merging xhtml files.
  - Changed fix for "Create TOC crash in Sigil 0.8.5" to reduce the
    degree of disconnecting to prevent lost signals on html
    resources.
  - Fix for missing audio and video mime types in OPFResource  and
    FolderKeeper.
  - Attempt to prevent Tidy from simply deleting all mathml during
    cleaning.
- previous updates from 0.8.5
  - Fix text resource not alwalys saving to disk.
  - Fix bug in missing CSS.
  - Fix create html toc crash bug.
  - Update some links in the help menu.
* Fri Mar 27 2015 ecsos@opensuse.org
- update to 0.8.4
  - Fix for removeall plugins bug where all plugins would remove
  all plugins regardless if the user clicked no instead of yes.
- previous updates from 0.8.3
  - 10.9.5 is now the minimum OS X version required.
    Only 10.10.1 has been tested.
  - -DCODE_SIGN_ID=XYZ option has been added to auto sign the app
    bundle on OS X.
  - Validation result plugins will auto close the Plugin Runner
    Dialog since the dialog has no real info and openes the
    validation pane with the results anyway.
  - New Plugin Preferences Support added
  - Plugins Manager will now remember last folder used
  - Support for building both Linux .deb and .rpm packages
  - Lots of Linux build support, compilation, installation, and
    documentation improvements
  - Qt 5.4 is now a minimum requirement.
  - Build changes to support update to latest Qt 5.4.0 and to
    use latest C++11 compiler
  - Numerous bugs fixed or worked around including:
  - Make Invocation of CSS W3C Online Validator more reliable
  - Fix to make Preview Window update after BookView to prevent
    memory corruption and crashes
  - Workaround Qt bug (font cache assertion) when using
    clearMemoryCaches()
  - see https://bugreports.qt.io/browse/QTBUG-43504
  - Properly handle loadFinsihed Signal in BookViewPreview to
    prevent clashes between BookView and Preview
  - Fix for Sigil memory use after it was freed bug
  - Workaround to the extent possible Qt bug with memory use after
    free using QWebInspectors
  - see https://bugreports.qt.io/browse/QTBUG-43725
  - Workaround to the extent possible Qt bug with memory use
    after free when closing MainWindows
  - see https://bugreports.qt.io/browse/QTBUG-43692
  - Bug fix to prevent crashes in KeyboardsShortcuts when accessing
    Preferences with multiple MainWindows
* Sat Jan 24 2015 ecsos@opensuse.org
- update to 0.8.2
  - Validator plugin type which can load validation results into
    the main window validation panel.
  - Corrections to Sigil Plugin Framework Documentation
  - Pull request #17: Fix typos in README.md
  - Additional python plugin interface features:
  - multiple plugin engines now allowed for plugins that
    work on both python 2.7 and python 3.4
  - launcher revision date interface
  - plugin stdout will now appear immediately in Sigil
  - Multiple plugin launcher bug fixes:
  - make parsing more robust to poorly formed xhtml
  - modified text iterator to follow spine order
  - bug fixes for readotherfile, and writeotherfile
  - bug fixes for guide types and setting the guide
* Tue Oct 28 2014 ecsos@opensuse.org
- update to 0.8.1
  - Set minimum OS X version to 10.9.0 in Info.plist so users
    trying to run on older versions of OS X will receive an error
    dialog instead of a crash dialog.
  - Set minimum Windows version to Vista in Installer so
    installation will error when trying to install on XP
    (which is not supported and Sigil binary packages won't run on).
  - Fix issue #21: Use Hunspell WORDCHARS to help in tokenization
    of words.
  - Pull request #19: Moving plugin description to ToolTips.
  - Pull request #20: Preserve current file name for future save
    as actions
    if appropriate.
  - Fix bug where save after using input plugin would fail.
* Mon Oct  6 2014 opensuse@dstoecker.de
- update to 0.8.0
  - Plugin framework.
  - Add the svg image tag as an svg inline element
    (not a block element) and add it as an empty element
    (TidyEmptyTags).
  - Allow user defined list of entities to preserve.
  - Pull request #16: Hardcode menu Plugins in UI, move it before
    menu Help.
  - Pull request #10: Add ability to move entries in TOC
    up and down.
  - Pull request #8: Allow pasting HTML as HTML or plain text in
    BookView.
* Tue Jun 24 2014 opensuse@dstoecker.de
- update to 0.7.4
* Wed Sep  4 2013 opensuse@dstoecker.de
- update to version 0.7.3
  Sigil 0.7.3 2013.08.03
  - Fix issue 2309: Compile failure due to case issue on m_lastFolderOpen.
  - Fix issue 2269: "Conflicts with:" always in English.
  - Fix issue 2186: Sigil 0.7.2 crashes on "Add existing files".
  - Fix issue 2232: The nbsp characters in UTF-8 files are converted to normal spaces.
  - Fix issue 2201: Save does not prompt for filename if filename not set
    after cancelling save operation.
  - Fix issue 2193: Incorrect country code used for Serbia.
  - Implement issue 2199: Mac, Don't open empty book by default.
  Sigil 0.7.2 2013.04.14
  - Implement issue 2129: Enhance archive filename encoding handling.
  - Implement issue 2128: Warnings for non-ASCII characters in filenames.
  - Implement issue 2113: Preview should zoom separately from other views.
  - Implement issue 1997: Tool to Add Cover image and file automatically.
  - Implement issue 1993: Find & Replace should have a Marked Text option.
  - Implement issue 2083: Enhance invalid OPF recovery.
  - Implement issue 2082: Improve performance of Book Browser refresh.
  - Fix issue 2170: Spellcheck should remember position after changing word.
  - Fix issue 2148: Don't delete cover image in "Delete unused media files".
  - Fix issue 2147: Doubleclick in Delete Files dialog can cause crash.
  - Fix issue 2143: Bulk rename with just a number for filename does not use correct number of 0s.
  - Fix issue 2121: Wait cursor shows when dialog is open while saving or opening.
  - Fix issue 2107: Heading not accepted due to split at end of file.
  - Fix issue 2110: Insert Special Character inserts wrong code for nnbsp.
  - Fix issue 2021: Importing UTF-16 encoded files results in empty file.
  - Fix issue 2088: Ctrl-click on text files does not work in Code View.
  - Fix Issue 2071: Anchor dialog has disabled text field.
  - Fix Issue 2077: Rename dialog incorrectly sized.
  - Fix issue 2081: Book Browser tooltips are not updated when semantics change or for cover images.
  - Fix issue 2080: OPF meta title not updated correctly for Add Semantic.
  - Fix issue 2079: UI Language dropdown does not show language names for entries containing _.
* Mon Mar 25 2013 opensuse@dstoecker.de
- update to 0.7.1
  - Implement issue 2058: Code View should be able to show resizable image.
  - Implement issue 2038: Spellcheck "change selected word to" should remember sorting order.
  - Implement issue 2043: Spellcheck should allow case-insensitive sorting.
  - Implement issue 2029: Save and open should warn if HTML files are not well formed.
  - Implement issue 2009: Add semantic tags to filenames in reports.
  - Implement issue 2028: Special characters should work in non-html files.
  - Implement issue 2027: Upgrade Boost to Boost 1.53.0.
  - Fix issue 2069: Work around for archives where filenames are not utf-8 encoded.
  - Fix issue 2068: ZIP general purpose bit 11 (utf-8) filename not set.
  - Fix issue 2061: Language code using wrong character to separate country code.
  - Fix issue 2057: Text selected across lines using Ctrl-F cannot be found with Find.
  - Fix issue 2036: Mark for Index can insert HTML tags into code making it invalid.
  - Fix issue 2041: Preview does not sync cursor after using Sigil for a while.
  - Fix issue 2030: The &#160; character is incorrectly converted to space on open.
  - Fix issue 2035: Index Editor entries with nbsp character don't match text.
  - Fix issue 2016: Find with wrap off and All HTML Files still wraps on last file.
  - Fix issue 2001: Spellcheck does not always highlight a word the first time.
  - Fix issue 2017: Clips pasted into some windows does not work correctly.
  - Fix issue 2008: Index adds extra comma in some cases.
* Sun Feb 24 2013 opensuse@dstoecker.de
- update to 0.7.0
  - Implement issue 1983: Set the tooltips of files in Book Browser to the filename.
  - Implement issue 1965: Allow opening files that are missing container.xml.
  - Implement issue 1975: HTML TOC and Index should use CSS files instead of inline stylesheet.
  - Implement issue 1968: Bookmark location in editing window.
  - Implement issue 1963: Table Of Contents window should default to expanded when opened or refreshed.
  - Implement issue 1953: Allow entering a list of new words into dictionary preferences.
  - Implement issue 1952: Add shortcut for Copy HTML file.
  - Implement issue 1951: Doubleclick on Image Report file should find next use of image.
  - Implement issue 1949: Add support for multiple active user dictionaries.
  - Implement issue 1947: Spellcheck dialog to manage all misspelled words at once.
  - Implement issue 62: Add document's css styles to menu.
  - Implement issue 1945: Allow editing of CSS while displaying page.
  - Implement issue 1661: Report list of all different characters in the book.
  - Implement issue 1746: Add Report for Links and Footnotes.
  - Implement issue 1941: Add Find & Replace option to wrap or not wrap searches.
  - Implement issue 1940: Update Insert Image to Insert File to support insert of audio/video.
  - Implement issue 1938: Update Delete Image files to Delete Media files to include audio/video.
  - Implement issue 1937: Add Report for All Files.
  - Implement issue 1936: Add Clip Bar toolbar with buttons for Clips and shortcuts for Clips.
  - Implement issue 1931: Change to QRegularExpression for most regexes.
  - Implement issue 1185: Edit Table of Contents without needing Generate TOC.
  - Implement issue 1929: Add support for playing audio and video files.
  - Implement issue 917: Sigil should support audio and video tags.
  - Implement issue 1928: Add well-formed check to HTML File Report.
  - Implement issue 1864: Allow Metadata Editor dialog to stay open while editing.
  - Implement issue 1871: Code View context menu should show clips even if word is misspelled.
  - Implement issue 1870: Saved Searches should use mode settings from Find & Replace.
  - Implement issue 1927: Add support for basic replacement Clips (e.g. span) in Book View.
  - Implement issue 20: Embedded fonts support.
  - Implement issue 1926: Upgrade to Qt5.
  - Implement issue 1924: Add dockable Clips window to select clips.
  - Implement issue 1925: Don't force well formed checks unless absolutely necessary.
  - Implement issue 1843: Preview should be real-time display of Code View.
  - Fix issue 1989: Problem with nested index entries.
  - Fix issue 1964: Correcting a word using spellcheck does not make file go to "not saved" state.
  - Fix issue 1961: Generate TOC should not create IDs for headings when it only points to filenames.
  - Fix issue 1857: CSS Highlighting inline styles inconsistent.
  - Fix issue 1946: Highlight misspelled words checkbox should be available in Preferences.
  - Fix issue 1943: Reports can crash if file has non well-formed xml.
  - Fix issue 1883: TOC window does not jump to right location for some entries.
  - Fix issue 1906: "Delete unused image files" deleting background images.
  - Fix issue 1874: Using Delete Unused Stylesheet Classes deletes pseudo-elements.
  - Fix issue 1939: CSS parser does not match wildcard selectors consistently.
  - Fix issue 1935: Improve speed of Index Editor autofill by removing progress dialog.
  - Fix issue 1891: Opening the Saved Searches expands all groups.
  - Fix issue 1934: Go To Style does not work with CSS filenames that have spaces in them.
  - Fix issue 1933: No message is displayed if Go To Style can't find a style.
  - Fix issue 1932: Replace All needs to be run twice in some cases.
  - Fix issue 1930: Fix Metadata language dropdown selection incorrect matching.
  - Fix issue 1775: Sigil-0.6.0 edit very slow with Thai e-Pub.
  - Fix issue 1764: Sigil crashes on KDE after rearranging text sections.
  - Fix issue 1720: Book View highlights text apparently randomly.
  - Fix issue 1923: CSS validation should use EPUB 2 profile.
  - Fix issue 1922: Invalid EPUB warning dialog is not long enough.
  - Fix issue 1918: Support import of tab separated entries for Index Editor.
  - Fix issue 1917: Keep selection when deleting unused images if an HTML file was selected.
  - Fix issue 1916: Allow Go To Style to work for link type text/x-oeb1-css.
  - Fix issue 1869: Backspace in Preferences - Shortcuts causes crash.
  - Fix issue 1818: Hyperlink of URL with & causes invalid code.
  - Fix issue 1824: Cursor position changes when saving the book.
* Sun Dec 16 2012 opensuse@dstoecker.de
- update to release 0.6.2
* Mon Nov  5 2012 opensuse@dstoecker.de
- Update to release 0.6.0
* Thu Aug 30 2012 toms@opensuse.org
- Added sigil-Dialogs-About.cpp.patch to disable __DATE__ and __TIME_
  warning message from rpmlint was:
  "Your file uses  __DATE and __TIME__ this causes the package to rebuild
  when not needed warning"
* Thu Aug 30 2012 toms@opensuse.org
- Updated to version 0.5.3 (2012.02.25):
  - Fix issue 1254: Bulk rename will stop if one name matches, context menu
    needs cleanup and warnings.
  - Fix issue 1268: Find/Replace all files does not search in book order,
    and other issues.
  - Fix issue 1266: Store user dictionary as UTF-8.
  - Ensure the checkmarks in add semantic are set correctly when selecting
    multiple files.
  - Fix issue 1030: Don't close if canceling out of a failed save.
  - Fix issue 1258: Find/Replace step by step in All HTML files is broken.
  For previous changes, see ChangeLog.txt
* Sat Aug  6 2011 toms@suse.de
- First initial release 0.3.4
